@@ -15,7 +15,7 @@ class MC(Cog):
     def __init__(self, bot):
         self.bot = bot
         self.bot.message_queue = {}
-        threading.Thread(target=self.bot.loop.call_soon_threadsafe, args=[self.bot.message_queue]).start()
+        threading.Thread(target=self.bot.loop.call_soon_threadsafe, args=[self.message_worker]).start()
 
     @command(name='mc')
     async def mc(self, ctx, cmd, *params):
